@@ -24,6 +24,7 @@
 G_BEGIN_DECLS
 
 #include <gtk/gtk.h>
+#include <dbus/dbus.h>
 #include "address-list.h"
 #include "locations-combo.h"
 #include "connection.h"
@@ -50,6 +51,9 @@ struct _GstNetworkTool
   GstAddressList *dns;
   GstAddressList *search;
 
+  /* bus, used for NM integration */
+  DBusConnection *bus_connection;
+
   GtkTreeModel *interfaces_model;
   GtkTreeView  *interfaces_list;
 
@@ -60,6 +64,7 @@ struct _GstNetworkTool
   GtkEntry *domain;
 
   GstConnectionDialog *dialog;
+  GtkWidget *host_aliases_dialog;
 };
 
 struct _GstNetworkToolClass
